@@ -30,8 +30,7 @@
 
 #include <map>
 #include <string>
-#include <cstring>
-#include <stdexcept>
+#include <exception>
 
 class ResourceException : public std::exception {
 protected:
@@ -50,7 +49,7 @@ public:
     Resource() { refs =0; };
     Resource(const std::string& resource_name) : resource_name(resource_name), refs(0) {};
     virtual ~Resource() {};
-    
+
     void setResourceName(const std::string& resource_name) {
         if(this->resource_name.empty()) this->resource_name = resource_name;
     };
@@ -74,10 +73,7 @@ public:
     virtual ~ResourceManager();
 
     void purge();
-
     void release(Resource* resource);
-    Resource* grab(const std::string& resource_name);
-    virtual Resource* create(const std::string& name) { return 0; };
 };
 
 #endif
