@@ -62,6 +62,9 @@ void SDLApp::initConsole() {
     CONSOLE_SCREEN_BUFFER_INFO buffer_info;
     if(GetConsoleScreenBufferInfo( GetStdHandle( STD_OUTPUT_HANDLE ), &buffer_info )) {
         existing_console = !(buffer_info.dwCursorPosition.X==0 && buffer_info.dwCursorPosition.Y==0);
+    // assume TERM env implies this is an existing terminal
+    } else if(getenv("TERM") != 0) {
+        existing_console = true;
     }
 
     // don't customize the console unless it was created for this program
@@ -173,7 +176,7 @@ void SDLApp::setClipboardText(const std::string& text) {
 #endif
 }
 
-void SDLAppInit(std::string apptitle, std::string execname) {
+void SDLAppInit(std::string apptitle, std::string execname, std::string exepath) {
     gSDLAppTitle = apptitle;
     gSDLAppExec  = execname;
 
@@ -181,22 +184,22 @@ void SDLAppInit(std::string apptitle, std::string execname) {
     std::string resource_dir = "data/";
     std::string fonts_dir    = "data/fonts/";
     std::string shaders_dir  = "data/shaders/";
+
 #ifdef _WIN32
 
     char szAppPath[MAX_PATH];
     GetModuleFileName(0, szAppPath, MAX_PATH);
 
     // Extract directory
-    std::string exepath = std::string(szAppPath);
+    std::string winexepath = std::string(szAppPath);
 
-    int pos = exepath.rfind("\\");
+    int pos = winexepath.rfind("\\");
 
-    std::string path = exepath.substr(0, pos+1);
+    std::string path = winexepath.substr(0, pos+1);
     conf_dir     = path + std::string("\\");
     resource_dir = path + std::string("\\data\\");
     fonts_dir    = path + std::string("\\data\\fonts\\");
     shaders_dir  = path + std::string("\\data\\shaders\\");
-
 #else
     //get working directory
     char cwd_buff[1024];
@@ -222,6 +225,17 @@ void SDLAppInit(std::string apptitle, std::string execname) {
         fonts_dir    = SDLAPP_RESOURCE_DIR + std::string("/fonts/");
         shaders_dir  = SDLAPP_RESOURCE_DIR + std::string("/shaders/");
     }
+    else if(!exepath.empty()) {
+        // make resource path relative to the directory of the executable
+        // if the resource directory doesn't exist
+        size_t pos = exepath.rfind("/");
+        if (pos != std::string::npos) {
+            std::string path = exepath.substr(0, pos+1);
+            resource_dir = path + std::string("data/");
+            fonts_dir    = path + std::string("data/fonts/");
+            shaders_dir  = path + std::string("data/shaders/");
+        }
+    }
 #endif
 
 #ifdef SDLAPP_FONT_DIR
