@@ -962,6 +962,14 @@ void GourceSettings::importGourceSettings(ConfFile& conffile, ConfSection* gourc
 
         font_file = entry->getString();
 
+        boost::filesystem::path font_file_path(font_file);
+
+        if(!boost::filesystem::exists(font_file_path)) {
+            conffile.invalidValueException(entry);
+        }
+
+        font_file = boost::filesystem::canonical(font_file_path).string();
+
         if(font_file.empty()) {
            conffile.invalidValueException(entry);
         }
